@@ -321,7 +321,7 @@ instance:
 
 >>> dir(db)
 ... # doctest: +NORMALIZE_WHITESPACE +ELLIPSIS +ALLOW_UNICODE
-[u'aggregate',
+[u'add_attributes',
  ...
  u'xgrid']
 
@@ -1040,4 +1040,4 @@ no_ops            = False
 from .db import connect, iquery, Array
 from .schema import Attribute, Dimension, Schema
 
-__version__ = '18.1.5'
+__version__ = '19.3.3'
